<?php
namespace BancoTalentos\Controllers;

use BancoTalentos\Services\AnexosService;
use Zeedhi\Framework\DTO\{ Request, Response };
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use BancoTalentos\Util\ExpectedException;

class AnexosController {
    /** @param AnexosService */
    protected $anexosService;

    public function __construct(
        AnexosService $anexosService
    ) {
        $this->anexosService = $anexosService;
    }

    public function getFoto(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $foto = $this->anexosService->getFotoFile();

            $dataset = [
                'foto' => $foto,
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function setFoto(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();
            $this->anexosService->setAnexo($row, true);
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getCategorias(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $categorias = $this->anexosService->getCategorias();

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipos(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $tipos = $this->anexosService->getTipos();

            $response->addDataSet(new DataSet('data', $tipos));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}