<?php
namespace BancoTalentos\Controllers;

use BancoTalentos\Services\DashboardService;
use Zeedhi\Framework\DTO\{ Request, Response };
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use BancoTalentos\Util\ExpectedException;

class DashboardController {
    /** @param DashboardService */
    protected $dashboardService;

    public function __construct(
        DashboardService $dashboardService
    ) {
        $this->dashboardService = $dashboardService;
    }

    public function getStatusCadastro(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $statusCadastro = $this->dashboardService->getStatusCadastro();

            $response->addDataSet(new DataSet('data', $statusCadastro));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getQtVagasRelacionadas(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $qtVagasRel = $this->dashboardService->getQtVagasRelacionadas();

            $response->addDataSet(new DataSet('data', $qtVagasRel));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getUltimaAtualizacao(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $ultAtu = $this->dashboardService->getUltimaAtualizacao();

            if ($ultAtu === false) {
                $ultAtu = [];
            }

            $response->addDataSet(new DataSet('data', $ultAtu));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

}