<?php
namespace BancoTalentos\Repositories;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class AnexosRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    public function getCategorias(
        int $nrOrg
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GER_CATEGDOCUMENTO
            WHERE
                IDATIVO = 'S' AND
                NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $categorias = $std->fetchAll();

        return $categorias;
    }

    public function getTipos(
        int $nrOrg
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GER_TIPODOCUMENTO
            WHERE
                IDATIVO = 'S' AND
                NRORG = :P_NRORG AND
                IDDOCUMENTOPUBLICO = 'S'
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $tipos = $std->fetchAll();

        return $tipos;
    }

    public function getCategoria(
        int $nrOrg,
        int $nrCategoria
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GER_CATEGDOCUMENTO
            WHERE
                IDATIVO = 'S' AND
                NRORG = :P_NRORG AND
                NRCATEGDOCUMENTO = :P_NRCATEG
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRCATEG' => $nrCategoria,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $categoria = $std->fetch();

        return $categoria;
    }

    public function getTipo(
        int $nrOrg,
        int $nrTipo
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GER_TIPODOCUMENTO
            WHERE
                IDATIVO = 'S' AND
                NRORG = :P_NRORG AND
                NRTIPODOCUMENTO = :P_NRTIPO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRTIPO' => $nrTipo,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $tipo = $std->fetch();

        return $tipo;
    }
}