<?php

namespace BancoTalentos\Repositories;

use BancoTalentos\Util\{ Repository, Util };

class GeralRepository extends Repository {
    public function getPais() {
        $sql = <<<SQL
            SELECT CDPAIS, NMPAIS
            FROM PAIS
            WHERE NRORG = :P_NRORG_PADRAO
            ORDER BY NMPAIS
SQL;
        $parameters = [
            'P_NRORG_PADRAO' => Util::DEFAULT_ORG
        ];

        return $this->get($sql, $parameters);
    }

    public function getGrauinstrucao() {
        $sql = <<<SQL
            SELECT *
            FROM GPE_GRAUINSTR
            WHERE NRORG = :P_NRORG_PADRAO
SQL;
        $parameters = [
            'P_NRORG_PADRAO' => Util::DEFAULT_ORG,
        ];

        return $this->get($sql, $parameters);
    }

    public function getEstadocivil() {
        $sql = <<<SQL
            SELECT *
            FROM ESTADOCIVIL
            WHERE NRORG = :P_NRORG_PADRAO
SQL;
        $parameters = [
            'P_NRORG_PADRAO' => Util::DEFAULT_ORG
        ];

        return $this->get($sql, $parameters);
    }

    public function getEstado($cdPais) {
        $sql = <<<SQL
            SELECT *
            FROM ESTADO
            WHERE NRORG = :P_NRORG_PADRAO
                AND CDPAIS = :P_CDPAIS
            ORDER BY NMESTADO
SQL;
        $parameters = [
            'P_NRORG_PADRAO'    => Util::DEFAULT_ORG,
            'P_CDPAIS'          => $cdPais,
        ];

        return $this->get($sql, $parameters);
    }

    public function getMunicipio($cdPais, $sgEstado) {
        $sql = <<<SQL
            SELECT
                CDMUNICIPIO,
                INITCAP(NMMUNICIPIO) NMMUNICIPIO,
                CDMUNICIBGE
            FROM MUNICIPIO
            WHERE NRORG = :P_NRORG_PADRAO
                AND IDATIVO = 'S'
                AND (CDPAIS = :P_CDPAIS OR :P_CDPAIS IS NULL)
                AND (SGESTADO = :P_SGESTADO OR :P_SGESTADO IS NULL)
            ORDER BY NMMUNICIPIO
SQL;
        $parameters = [
            'P_NRORG_PADRAO'    => Util::DEFAULT_ORG,
            'P_CDPAIS'          => $cdPais,
            'P_SGESTADO'        => $sgEstado,
        ];

        return $this->get($sql, $parameters);
    }

    public function getNacionalidade() {
        $sql = <<<SQL
            SELECT
                NRNACIONALIDADE,
                DSNACIONALIDADE,
                CDRAIS,
                NRORG,
                DTINCLUSAO,
                DTULTATU,
                NRORGINCLUSAO,
                CDOPERINCLUSAO,
                NRORGULTATU,
                CDOPERULTATU,
                NVL(CDPAIS, '0000') AS CDPAIS
            FROM GPE_NACIONALIDADE
            WHERE NRORG = :P_NRORG_PADRAO
            ORDER BY DSNACIONALIDADE
SQL;
        $parameters = [
            'P_NRORG_PADRAO'    => Util::DEFAULT_ORG,
        ];

        return $this->get($sql, $parameters);
    }

    public function getLogradouro() {
        $sql = <<<SQL
            SELECT * FROM LOGRADOURO WHERE NRORG = :P_NRORG_PADRAO
SQL;
        $parameters = [
            'P_NRORG_PADRAO'    => Util::DEFAULT_ORG,
        ];

        return $this->get($sql, $parameters);
    }
}