<?php
namespace BancoTalentos\Repositories;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class PerfilRepository {
    /** @var EntityManager */
    protected $entityManager;

    /** @var Connection */
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    public function getTipoFormacaoParc(
        int $nrOrg,
        int $nrOrgPadrao
    ): array {
        $sql = <<<SQL
            SELECT
                F.*
            FROM
                DES_TIPOFORMACAO F
            WHERE
                F.NRORG = :P_NRORG OR
                F.NRORG = :P_NRORG_PADRAO
SQL;

        $params = [
            'P_NRORG'           => $nrOrg,
            'P_NRORG_PADRAO'    => $nrOrgPadrao,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $tiposFormacao = $std->fetchAll();

        return $tiposFormacao;
    }

    public function getCursoAcademico(): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                DES_CURSO
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute();

        $cursos = $std->fetchAll();

        return $cursos;
    }

    public function getInstituicaoEstrutura(
        int $nrOrg,
        int $nrOrgPadrao
    ): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                PARCNEGOCIO
            WHERE
                NRORG IN (:P_NRORG, :P_NRORG_PADRAO) AND
                CDTIPOPARCPRINCIPAL = 'ESTRUTURA'
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRORG_PADRAO' => $nrOrgPadrao,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $instituicoes = $std->fetchAll();

        return $instituicoes;
    }

    public function getAreaFormacao(): array {
        $sql = <<<SQL
            SELECT
                *
            FROM
                DES_AREAFORMACAO
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute();

        $areas = $std->fetchAll();

        return $areas;
    }

    public function getIdiomas(): array {
        $sql = <<<SQL
            SELECT
                CDIDIOM,
                NMIDIOMA
            FROM
                IDIOMA
            ORDER BY
                NMIDIOMA
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute();

        $result = $std->fetchAll();

        return $result;
    }

    public function getOcupacoes(
        int $nrOrg
    ): array {
        $sql = <<<SQL
            SELECT
                H.NROCUPACAOM,
                NROCUPACAOH,
                NMOCUPACAOH,
                M.NRORG
            FROM
                GPE_OCUPACAOH H
                JOIN GPE_OCUPACAOM M ON
                    H.NROCUPACAOM = M.NROCUPACAOM AND
                    H.NRORG = M.NRORG
            WHERE
                M.NRORG = :P_NRORG
            ORDER BY
                M.NROCUPACAOM
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetchAll();

        return $result;
    }

    public function getTiposServico(
        int $nrOrg
    ): array {
        $sql = <<<SQL
            SELECT
                M.NRTIPOVINCULOM,
                M.NRORG,
                NRTIPOVINCULOH,
                NMTIPOVINCULOH
            FROM
                GPE_TIPOVINCULOM M
                JOIN GPE_TIPOVINCULOH H ON
                    M.NRORG = H.NRORG AND
                    M.NRTIPOVINCULOM = H.NRTIPOVINCULOM
            WHERE
                M.NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetchAll();

        return $result;
    }

    public function getMotivosRescisao(): array {
        $sql = <<<SQL
            SELECT
                NRMOTIVORESC,
                NMMOTIVORESC
            FROM
                GPE_MOTIVORESC
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute();

        $result = $std->fetchAll();

        return $result;
    }

    public function getDadosPessoais(
        int $nrOrg,
        int $nrParcNegocio
    ) {
        $sql = <<<SQL
            SELECT
                PH.NRRGPESSOA,
                PH.CDEXRGPESSOA,
                TO_CHAR(PH.DTEXRGPESSOA, 'DD/MM/YYYY') DTEXRGPESSOA,
                PH.NRPESSOA,
                NRPESSOAH,
                NMESTADO,
                IDPOSSUIFILHO,
                DSNACIONALIDADE,
                G.NMGRAUINSTR,
                NMMUNICIPIO,
                NMPAIS,
                NRNACIONALID,
                O.NRPARCNEGOCIO,
                O.NRORG,
                TO_CHAR(DTNASCPESSOA, 'DD/MM/YYYY') DTNASCPESSOA,
                IDSEXOPESSOA,
                CDESTACIVIL,
                PA.CDPAIS,
                PH.SGESTADO,
                PH.CDMUNICIPIO,
                PH.NRGRAUINSTR,
                NRIDADEFILHO,
                NRCPFPESSOA,
                NMOPERADOR,
                CDOPERADOR,
                DSEMAILOPER
            FROM
                    OPERADOR O
                JOIN GPE_PESSOA        P ON O.NRPARCNEGOCIO = P.NRPARCNEGOCIO
                                    AND O.NRORG = P.NRORG
                JOIN GPE_PESSOAH       PH ON PH.NRPESSOA = P.NRPESSOA
                                    AND PH.NRORG = P.NRORG
                LEFT JOIN PAIS              PA ON PH.CDPAIS = PA.CDPAIS
                LEFT JOIN MUNICIPIO         M ON PH.CDMUNICIPIO = M.CDMUNICIPIO
                LEFT JOIN GPE_GRAUINSTR     G ON PH.NRGRAUINSTR = G.NRGRAUINSTR
                LEFT JOIN GPE_NACIONALIDADE NA ON PH.NRNACIONALID = NA.NRNACIONALIDADE
                LEFT JOIN ESTADO            E ON PH.SGESTADO = E.SGESTADO
            WHERE
                    O.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                AND O.NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }

    public function getDadosAdicionais(
        int $nrOrg,
        int $nrParcNegocio
    ) {
        $sql = <<<SQL
            SELECT
                NRCARTHABPES,
                DSCATEGHABCART,
                TO_CHAR(DTVALHABCARTPES, 'DD/MM/YYYY') DTVALHABCARTPES,
                DSAPRESENTACAO,
                DSAREAINTERESSE,
                DSOBSERVACAO,
                NRAPRESENTACAOCAND,
                AP.NRORG,
                AP.NRPARCNEGOCIO,
                NRPESSOAH
            FROM
                    DES_APRESENTACAOCAND AP
                JOIN GPE_PESSOA  PESSOA ON PESSOA.NRPARCNEGOCIO = AP.NRPARCNEGOCIO
                                        AND PESSOA.NRORG = AP.NRORG
                JOIN GPE_PESSOAH PESSOAH ON PESSOAH.NRPESSOA = PESSOA.NRPESSOA
                                            AND PESSOAH.NRORG = PESSOA.NRORG
            WHERE
                    AP.NRORG = :P_NRORG
                AND AP.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }

    public function getEndereco(
        int $nrOrg,
        int $nrParcNegocio
    ) {
        $sql = <<<SQL
            SELECT
                E.NRORG,
                E.NRPARCNEGOCIO,
                NRENDERECOPARC,
                NRCEPENDERECO,
                E.CDPAIS,
                E.CDMUNICIPIO,
                E.SGESTADO,
                E.CDLOGRADOURO,
                DSCOMPLEENDERECO,
                DSENDERECO,
                NMBAIRROENDERECO,
                NRIMOVELENDERECO,
                DSLOGRADOURO,
                NMMUNICIPIO,
                NMESTADO,
                NMPAIS
            FROM
                    ENDERECOPARC E
                LEFT JOIN LOGRADOURO L ON L.CDLOGRADOURO = E.CDLOGRADOURO
                LEFT JOIN PAIS       P ON E.CDPAIS = P.CDPAIS
                LEFT JOIN MUNICIPIO  M ON E.CDMUNICIPIO = M.CDMUNICIPIO
                LEFT JOIN ESTADO     ES ON E.SGESTADO = ES.SGESTADO
            WHERE
                    E.NRORG = :P_NRORG
                AND E.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }

    public function getContato(
        int $nrOrg,
        int $nrParcNegocio
    ) {
        $sql = <<<SQL
            SELECT
                (
                    SELECT CDCOMUNICAPARC
                    FROM COMUNICAPARC
                    WHERE
                        NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND
                        NRORG = :P_NRORG AND
                        CDFORMACOMU = '08'
                ) REDESOCIAL,
                (
                    SELECT CDCOMUNICAPARC
                    FROM COMUNICAPARC
                    WHERE
                        NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND
                        NRORG = :P_NRORG AND
                        CDFORMACOMU = '07'
                ) HOMEPAGE,
                (
                    SELECT
                        (CASE
                            WHEN CDPREFIXCOMUPARC IS NULL
                                THEN CDCOMUNICAPARC
                            ELSE
                                '(' || CDPREFIXCOMUPARC || ')' || CDCOMUNICAPARC
                        END) CDCOMUNICAPARC
                    FROM COMUNICAPARC
                    WHERE
                        NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND
                        NRORG = :P_NRORG AND
                        CDFORMACOMU = '01'
                ) TELPRINCIPAL,
                (
                    SELECT
                        (CASE
                            WHEN CDPREFIXCOMUPARC IS NULL
                                THEN CDCOMUNICAPARC
                            ELSE
                                '(' || CDPREFIXCOMUPARC || ')' || CDCOMUNICAPARC
                        END) CDCOMUNICAPARC
                    FROM COMUNICAPARC
                    WHERE
                        NRPARCNEGOCIO = :P_NRPARCNEGOCIO AND
                        NRORG = :P_NRORG AND
                        CDFORMACOMU = '02'
                ) CELPARTIC
            FROM DUAL
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }

    public function getFormacao(
        int $nrOrg,
        int $nrParcNegocio
    ): array {
        $sql = <<<SQL
            SELECT
                F.NRPERIODO,
                F.DTINCLUSAO,
                F.NRCURSO,
                NRCARGAHORARIA,
                DES_AREAFORMACAO_NRORG,
                F.NRORG,
                NRFORMACAO,
                DSTIPOFORMACAO,
                F.NRPARCNEGOCIO,
                F.NRAREAFORMACAO,
                NMAREAFORMACAO,
                TO_CHAR(DTINICIO, 'DD/MM/YYYY') DTINICIO,
                TO_CHAR(DTFIM, 'DD/MM/YYYY')    DTFIM,
                DSCURSO,
                DSINSTITUICAO,
                NMCURSO,
                F.DSOBSERVACAO,
                F.NRTIPOFORMACAO,
                CDIDIOMA,
                IDNVIDIOMA
            FROM
                DES_FORMACAO     F
                LEFT JOIN DES_AREAFORMACAO AREA ON F.NRAREAFORMACAO = AREA.NRAREAFORMACAO
                                                OR ( F.NRAREAFORMACAO IS NULL
                                                        AND AREA.NRAREAFORMACAO IS NULL )
                JOIN DES_CURSO        CURSO ON CURSO.NRCURSO = F.NRCURSO
                JOIN DES_TIPOFORMACAO TIPO ON TIPO.NRTIPOFORMACAO = F.NRTIPOFORMACAO
            WHERE
                    F.NRORG = :P_NRORG
                AND F.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetchAll();

        return $result;
    }

    public function getExperiencia(
        int $nrOrg,
        int $nrParcNegocio
    ): array {
        $sql = <<<SQL
            SELECT
                NMOCUPACAOH,
                IDPOSSUIEXPERIENCIA,
                OCH.NROCUPACAOH,
                EM.NRORG,
                NREMPREGOANTERIOR,
                NRPARCNEGOCIO,
                DSEMPRESA,
                TO_CHAR(DTINICIO, 'DD/MM/YYYY') DTINICIO,
                TO_CHAR(DTFIM, 'DD/MM/YYYY')    DTFIM,
                NMPAIS,
                EM.CDPAIS,
                EM.SGESTADO,
                NMMUNICIPIO,
                EM.CDMUNICIPIO,
                EM.NRMOTIVORESC,
                DSREFERENCIA,
                OCM.NROCUPACAOM,
                DSOCUPACAO,
                NRREMUNERACAO,
                DSOBSERVACAO,
                IDCOMISSAO,
                IDTIPOSERVICO,
                DSTELREFERENCIA
            FROM
                GPE_EMPREGANTERIOR EM
                LEFT OUTER JOIN GPE_MOTIVORESC     MO ON EM.NRMOTIVORESC = MO.NRMOTIVORESC
                                                    AND EM.NRORG = MO.NRORG
                LEFT OUTER JOIN GPE_OCUPACAOM      OCM ON OCM.NROCUPACAOM = EM.NROCUPACAOM
                                                    AND EM.NRORG = OCM.NRORG
                LEFT OUTER JOIN GPE_OCUPACAOH      OCH ON OCH.NROCUPACAOM = OCM.NROCUPACAOM
                                                    AND OCH.NRORG = OCM.NRORG
                LEFT OUTER JOIN PAIS               P ON EM.CDPAIS = P.CDPAIS
                LEFT OUTER JOIN MUNICIPIO          M ON M.CDMUNICIPIO = EM.CDMUNICIPIO
            WHERE
                    EM.NRORG = :P_NRORG
                AND NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetchAll();

        return $result;
    }

    public function getArquivos(
        int $nrOrg,
        int $nrParcNegocio,
        string $idFoto
    ): array {
        $sql = <<<SQL
            SELECT
                NRANEXO,
                NRORG,
                NRPARCNEGOCIO,
                NMANEXO,
                DSREFERENCIA,
                IDTYPE,
                DSPATH,
                DSURL,
                TO_CHAR(DTINCLUSAO, 'DD/MM/YYYY') DTINCLUSAO,
                TO_CHAR(DTULTATU, 'DD/MM/YYYY')   DTULTATU,
                CDOPERINCLUSAO,
                CDOPERULTATU,
                NRCATEGDOCUMENTO,
                NRTIPODOCUMENTO
            FROM
                GPE_ANEXOS
            WHERE
                    NRORG = :P_NRORG
                AND NRPARCNEGOCIO = :P_NRPARCNEGOCIO
                AND IDFOTO = :P_IDFOTO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
            'P_IDFOTO' => $idFoto,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetchAll();

        return $result;
    }
}