<?php
namespace BancoTalentos\Repositories;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class PessoaRepository {
    /** @var EntityManager */
    protected $entityManager;

    /** @var Connection */
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    public function getPessoa(
        int $nrOrg,
        int $nrPessoa
    ) {
        $sql = <<<SQL
            SELECT *
            FROM
                GPE_PESSOA PM
                JOIN GPE_PESSOAH PH ON
                    PH.NRORG = PM.NRORG AND
                    PH.NRPESSOA = PM.NRPESSOA AND
                    PH.DTMESCOMPETENC = (
                        SELECT MAX(PH1.DTMESCOMPETENC)
                        FROM GPE_PESSOAH PH1
                        WHERE
                            PH1.NRORG = PM.NRORG AND
                            PH1.NRPESSOA = PM.NRPESSOA AND
                            PH1.DTMESCOMPETENC <= SYSDATE
                    )
            WHERE
                PM.NRORG = :P_NRORG AND
                PM.NRPESSOA = :P_NRPESSOA
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPESSOA' => $nrPessoa,
        ];

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        $result = $query->fetch();
        return $result;
    }

    /** @return array|false */
    public function getPessoaByNrParcNegocio(
        int $nrOrg,
        int $nrParcNegocio
    ) {
        $sql = <<<SQL
            SELECT *
            FROM
                GPE_PESSOA PM
                JOIN GPE_PESSOAH PH ON
                    PH.NRORG = PM.NRORG AND
                    PH.NRPESSOA = PM.NRPESSOA AND
                    PH.DTMESCOMPETENC = (
                        SELECT MAX(PH1.DTMESCOMPETENC)
                        FROM GPE_PESSOAH PH1
                        WHERE
                            PH1.NRORG = PM.NRORG AND
                            PH1.NRPESSOA = PM.NRPESSOA AND
                            PH1.DTMESCOMPETENC <= SYSDATE
                    )
            WHERE
                PM.NRORG = :P_NRORG AND
                PM.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPARCNEGOCIO' => $nrParcNegocio,
        ];

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        $result = $query->fetch();
        return $result;
    }

    public function getPessoaHByNrPessoa(
        int $nrOrg,
        int $nrPessoa
    ) {
        $sql = <<<SQL
            SELECT *
            FROM
                GPE_PESSOAH PH
            WHERE
                PH.NRORG = :P_NRORG AND
                PH.NRPESSOA = :P_NRPESSOA AND
                PH.DTMESCOMPETENC = (
                    SELECT MAX(PH1.DTMESCOMPETENC)
                    FROM GPE_PESSOAH PH1
                    WHERE
                        PH1.NRORG = PH.NRORG AND
                        PH1.NRPESSOA = PH.NRPESSOA AND
                        PH1.DTMESCOMPETENC <= SYSDATE
                )
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRPESSOA' => $nrPessoa,
        ];

        $query = $this->connection->prepare($sql);
        $query->execute($params);

        $result = $query->fetch();
        return $result;
    }
}