<?php

namespace BancoTalentos\Services;

use BancoTalentos\Util\{BTParameters, NovoCodigo, Repositories, Service, Utilities};
use BancoTalentos\Repositories\AnexosRepository;
class AnexosService extends Service {
    /** @var Utilities */
    protected $utilities;

    /** @var BTParameters */
    protected $btParameters;

    /** @var AnexosRepository */
    protected $anexosRepository;

    public function __construct(
        Utilities $utilities,
        BTParameters $bTParameters,
        AnexosRepository $anexosRepository
    ) {
        $this->utilities = $utilities;
        $this->btParameters = $bTParameters;
        $this->anexosRepository = $anexosRepository;
    }


    public function getEntityRepositoryName(): string {
        return Repositories::GPE_ANEXOS;
    }

    public function getEntityKeysName(): array {
        return [
            'NRORG',
            'NRANEXO',
        ];
    }

    public function setAnexo(
        array $row,
        $foto = false
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdOperador();

        if ($foto) {
            $this->removeFoto();
        }

        $base64 = (string) $row['FILE'];
        $type = $row['TYPE'] ?? $this->utilities->getFileMIMEType($base64);

        $directory = $foto ?
            "BTL/$nrOrg/Fotos/" :
            "BTL/$nrOrg/Documentos/";

        $idFoto = $foto ? 'S' : 'N';

        $dsReferencia = $foto ? 'Foto' : $row['DSREFERENCIA'];

        $name = (string) $row['NMANEXO'];

        $filePath = $this->utilities->saveFileOnFileServer(
            $base64, null, $nrOrg, $directory,
            $name, null, false
        );

        $nrAnexo = NovoCodigo::geraCodigo($nrOrg, 'GPE_ANEXOS');

        $rowSet = [
            'CDOPERINCLUSAO' => $cdOperador,
            'NRORGINCLUSAO' => $nrOrg,
            'DTINCLUSAO' => new \DateTime(),
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'IDTYPE' => $type,
            'IDFOTO' => $idFoto,
            'NRANEXO' => $nrAnexo,
            'DSPATH' => $filePath,
            'DSREFERENCIA' => $dsReferencia,
            'NMANEXO' => $name,
            'IDDOCUMENTOMODELO' => 'N',
        ];

        $this->set($rowSet);
    }

    public function removeFoto(): void {
        $foto = $this->getFoto();

        if (!$foto) {
            return;
        }

        $path = $foto->getDspath();

        $rowRemoveFoto = [
            'NRORG' => $foto->getNrorg(),
            'NRANEXO' => $foto->getNranexo(),
            'NRPARCNEGOCIO' => $foto->getNrparcnegocio(),
        ];

        $this->remove($rowRemoveFoto);

        $this->utilities->deleteFile($path);
    }

    public function getFoto() {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $searchRow = [
            'NRORG' => $nrOrg,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'IDFOTO' => 'S',
        ];

        $foto = $this->find($searchRow, ['NRORG', 'NRPARCNEGOCIO', 'IDFOTO']);

        if ($foto) {
            return $foto;
        }

        return false;
    }

    public function getFotoFile() {
        $foto = $this->getFoto();

        if (!$foto) {
            return false;
        }

        $path = $foto->getDspath();
        $file = $this->utilities->downloadFile($path);

        return $file;
    }

    public function getCategorias(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $categorias = $this->anexosRepository->getCategorias($nrOrg);

        return $categorias;
    }

    public function getTipos(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $tipos = $this->anexosRepository->getTipos($nrOrg);

        return $tipos;
    }

    public function getCategoria(
        int $nrCategoria
    ) {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $categoria = $this->anexosRepository->getCategoria($nrOrg, $nrCategoria);

        return $categoria;
    }

    public function getTipo(
        int $nrTipo
    ) {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $tipo = $this->anexosRepository->getTipo($nrOrg, $nrTipo);

        return $tipo;
    }
}