<?php

namespace BancoTalentos\Services;

use BancoTalentos\Util\{ Util, HcmServices, BTParameters, NovoCodigo};
use BancoTalentos\Repositories\ApresentacaoCandRepository;


class ApresentacaoCandService {
    /** @var BTParameters */
    protected $btParameters;

    /** @var ApresentacaoCandRepository */
    protected $apresentacaoCandRepository;

    public function __construct(
        BTParameters $bTParameters,
        ApresentacaoCandRepository $apresentacaoCandRepository
    ) {
        $this->btParameters = $bTParameters;
        $this->apresentacaoCandRepository = $apresentacaoCandRepository;
    }

    public function insert(array $row): int {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $nrApresentacaoCand = NovoCodigo::geraCodigo(
            $nrOrg, 'DES_APRESENTACAOCAND', 1, 10, true, false
        );

        $params = [
            'NRORG' => $nrOrg,
            'CDOPERADOR' => $cdOperador,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRAPRESENTACAOCAND' => $nrApresentacaoCand,
            'DSAPRESENTACAO' => $row['DSAPRESENTACAO'] ?? null,
            'DSOBSERVACAO' => $row['DSOBSERVACAO'] ?? null,
            'DSAREAINTERESSE' => $row['DSAREAINTERESSE'] ?? null,
        ];

        $this->apresentacaoCandRepository->insert($params);

        return $nrApresentacaoCand;
    }

    public function update(array $row) {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $params = [
            'NRORG' => $nrOrg,
            'CDOPERADOR' => $cdOperador,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'DSAPRESENTACAO' => $row['DSAPRESENTACAO'] ?? null,
            'DSOBSERVACAO' => $row['DSOBSERVACAO'] ?? null,
            'DSAREAINTERESSE' => $row['DSAREAINTERESSE'] ?? null,
        ];

        $this->apresentacaoCandRepository->update($params);
    }

    public function get() {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $result = $this->apresentacaoCandRepository->get($nrOrg, $nrParcNegocio);
        return $result;
    }

    public function save($row) {
        $apresentacaoCand = $this->get();
        $nrApresentacaoCand = null;

        if ($apresentacaoCand) {
            $this->update($row);
            $nrApresentacaoCand = $apresentacaoCand['NRAPRESENTACAOCAND'];
        } else {
            $nrApresentacaoCand = $this->insert($row);
        }

        return $nrApresentacaoCand;
    }
}