<?php
namespace BancoTalentos\Services;

use BancoTalentos\Util\{
    Util,
    HcmServices,
    BTParameters,
    DateUtil,
    NovoCodigo,
    Utilities
};
use BancoTalentos\Repositories\PerfilRepository;
use Doctrine\ORM\EntityManager;
use BancoTalentos\Services\{
    PessoaHService,
    ParceiroNegocioService,
    OperadorService,
    ApresentacaoCandService,
    EnderecoParcService,
    ComunicaParcService,
    FormacaoService,
    EmpregAnteriorService,
    AnexosService
};
use Teknisa\Model\Geral\Entities\Comunicaparc;

class PerfilService {
    /** @var BTParameters */
    protected $btParameters;

    /** @var HcmServices */
    protected $hcmServices;

    /** @var PerfilRepository */
    protected $perfilRepository;

    /** @var PessoaHService */
    protected $pessoaHService;

    /** @var ParceiroNegocioService */
    protected $parceiroNegocioService;

    /** @var EntityManager */
    protected $entityManager;

    /** @var OperadorService */
    protected $operadorService;

    /** @var ApresentacaoCandService */
    protected $apresentacaoCandService;

    /** @var EnderecoParcService */
    protected $enderecoParcService;

    /** @var ComunicaParcService */
    protected $comunicaParcService;

    /** @var FormacaoService */
    protected $formacaoService;

    /** @var EmpregAnteriorService */
    protected $experienciaService;

    /** @var Utilities */
    protected $utilities;

    /** @var AnexosService */
    protected $anexosService;

    private const ENTITY_DEFAULT_CONFIG = [
        'SET_DEFAULT_FIELDS'    => false,
        'PERSIST'               => false,
        'FLUSH'                 => false,
        'PENDING'               => true,
    ];

    public function __construct(
        BTParameters $btParameters,
        HcmServices $hcmServices,
        PerfilRepository $perfilRepository,
        PessoaHService $pessoaHService,
        ParceiroNegocioService $parceiroNegocioService,
        EntityManager $entityManager,
        OperadorService $operadorService,
        ApresentacaoCandService $apresentacaoCandService,
        EnderecoParcService $enderecoParcService,
        ComunicaParcService $comunicaParcService,
        FormacaoService $formacaoService,
        EmpregAnteriorService $experienciaService,
        Utilities $utilities,
        AnexosService $anexosService
    ) {
        $this->btParameters = $btParameters;
        $this->hcmServices = $hcmServices;
        $this->perfilRepository = $perfilRepository;
        $this->pessoaHService = $pessoaHService;
        $this->parceiroNegocioService = $parceiroNegocioService;
        $this->entityManager = $entityManager;
        $this->operadorService = $operadorService;
        $this->apresentacaoCandService = $apresentacaoCandService;
        $this->enderecoParcService = $enderecoParcService;
        $this->comunicaParcService = $comunicaParcService;
        $this->formacaoService = $formacaoService;
        $this->experienciaService = $experienciaService;
        $this->utilities = $utilities;
        $this->anexosService = $anexosService;
    }

    public function generateResume(): string {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $nmOperador = $this->btParameters->getNmOperador();
        $pathFoto = '';

        $competencia = date('01/m/Y');
        $reportName = 'curriculo_candidato';

        $route = 'generateBirtReport';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'reportName' => $reportName,
                'P_NRORG' => $nrOrg,
                'P_NRPARCNEGOCIO' => $nrParcNegocio,
                'P_NMOPERADOR' => $nmOperador,
                'P_COMPETENCIA' => $competencia,
                'P_PATH_FOTO' => $pathFoto,
            ],
        ];

        $response = $this->hcmServices->send($route, $params, $nrOrg);
        $reportLink = (string) $response['dataset'][$route]['link'];

        return $reportLink;
    }

    public function getTipoFormacaoParc(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrOrgPadrao = (int) $this->btParameters->getNrOrg();

        $result = $this->perfilRepository->getTipoFormacaoParc($nrOrg, $nrOrgPadrao);
        return $result;
    }

    public function getCursoAcademico(): array {
        $result = $this->perfilRepository->getCursoAcademico();
        return $result;
    }

    public function getInstituicaoEstrutura(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrOrgPadrao = (int) $this->btParameters->getNrOrg();

        $result = $this->perfilRepository->getInstituicaoEstrutura($nrOrg, $nrOrgPadrao);
        return $result;
    }

    public function getAreaFormacao(): array {
        $result = $this->perfilRepository->getAreaFormacao();
        return $result;
    }

    public function getIdiomas(): array {
        $result = $this->perfilRepository->getIdiomas();
        return $result;
    }

    public function getOcupacoes(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $result = $this->perfilRepository->getOcupacoes($nrOrg);
        return $result;
    }

    public function getTiposServico(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $result = $this->perfilRepository->getTiposServico($nrOrg);
        return $result;
    }

    public function getMotivosRescisao(): array {
        $result = $this->perfilRepository->getMotivosRescisao();
        return $result;
    }

    public function getPerfilData(): array {
        $perfilData = [];

        $perfilData['dadosPessoais' ] = $this->getDadosPessoais();
        $perfilData['adicionais'    ] = $this->getDadosAdicionais();
        $perfilData['endereco'      ] = $this->getEndereco();
        $perfilData['contato'       ] = $this->getContato();
        $perfilData['formacao'      ] = $this->getFormacao();
        $perfilData['experiencia'   ] = $this->getExperiencia();
        $perfilData['documentos'    ] = $this->getDocumentos();
        $perfilData['foto'          ] = $this->getFoto();

        return $perfilData;
    }

    public function getDadosPessoais(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $dadosPessoais = $this->perfilRepository->getDadosPessoais($nrOrg, $nrParcNegocio);

        return $dadosPessoais === false ? [] : $dadosPessoais;
    }

    public function getDadosAdicionais(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $dadosAdicionais = $this->perfilRepository->getDadosAdicionais($nrOrg, $nrParcNegocio);

        return $dadosAdicionais === false ? [] : $dadosAdicionais;
    }

    public function getEndereco(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $endereco = $this->perfilRepository->getEndereco($nrOrg, $nrParcNegocio);

        return $endereco === false ? [] : $endereco;
    }

    public function getContato(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $contato = $this->perfilRepository->getContato($nrOrg, $nrParcNegocio);

        return $contato === false ? [] : $contato;
    }

    public function getFormacao(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $formacao = $this->perfilRepository->getFormacao($nrOrg, $nrParcNegocio);

        return $formacao === false ? [] : $formacao;
    }

    public function getExperiencia(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $experiencia = $this->perfilRepository->getExperiencia($nrOrg, $nrParcNegocio);

        return $experiencia === false ? [] : $experiencia;
    }

    public function getDocumentos(): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $documentos = $this->perfilRepository->getArquivos($nrOrg, $nrParcNegocio, 'N');

        foreach ($documentos as &$documento) {
            $nrCategoria = $documento['NRCATEGDOCUMENTO'];
            $nmCategoria = null;

            $nrTipo = $documento['NRTIPODOCUMENTO'];
            $nmTipo = null;

            if ($nrCategoria) {
                $categoria = $this->anexosService->getCategoria($nrCategoria);
                $nmCategoria = $categoria['NMCATEGDOCUMENTO'] ?? null;
            }

            if ($nrTipo) {
                $tipo = $this->anexosService->getTipo($nrTipo);
                $nmTipo = $tipo['NMTIPODOCUMENTO'] ?? null;
            }

            $documento['NMCATEGDOCUMENTO'] = $nmCategoria;
            $documento['NMTIPODOCUMENTO'] = $nmTipo;
        }

        return $documentos === false ? [] : $documentos;
    }

    public function getFoto() {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $arquivos = $this->perfilRepository->getArquivos($nrOrg, $nrParcNegocio, 'S');
        $foto = $arquivos[0]['DSPATH'] ?? null;


        return $foto;
    }

    public function salvarDadosPessoais(array $row): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $row['DTULTATU'] = new \DateTime();
        $row['NRORGULTATU'] = $nrOrg;
        $row['CDOPERULTATU'] = $cdOperador;
        $row['NRPARCNEGOCIO'] = $nrParcNegocio;
        $row['NRORG'] = $nrOrg;

        foreach ($row as $key => $value) {
            if ($value === '') {
                $row[$key] = null;
            }
        }

        if (isset($row['DTNASCPESSOA'])) {
            $row['DTNASCPESSOA'] = DateUtil::getDataDeString($row['DTNASCPESSOA']);
        }

        if (isset($row['DTEXRGPESSOA'])) {
            $row['DTEXRGPESSOA'] = DateUtil::getDataDeString($row['DTEXRGPESSOA']);
        }

        $parcNegocioRow = [
            'NMPRINCIPALPARC' => $row['NMOPERADOR'],
            'NMSECUNDARIPARC' => $row['NMOPERADOR'],
            'DTNASCIFUNDPARC' => $row['DTNASCPESSOA'] ?? null,
            'NRINSCRICAOPARC' => $row['NRCPFPESSOA'] ?? null,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRORG' => $nrOrg,
        ];

        $pessoaHRow = $row;
        [$primeiroNome, $segundoNome, $ultimoNome] = Util::decompoeNomeCompleto($row['NMOPERADOR']);

        $pessoaHRow['NMPESSOA'] = $row['NMOPERADOR'];
        $pessoaHRow['DSPRINOMEPESS'] = $primeiroNome;
        $pessoaHRow['DSNOMEMEIOPESS'] = $segundoNome;
        $pessoaHRow['DSULTNOMEPESS'] = $ultimoNome;

        $operadorRow = $row;

        $operadorRow['DTNASCIMENTO'] = $row['DTNASCPESSOA'];

        $this->entityManager->beginTransaction();

        try {
            $this->parceiroNegocioService->update($parcNegocioRow, self::ENTITY_DEFAULT_CONFIG);
            $this->pessoaHService->update($pessoaHRow, self::ENTITY_DEFAULT_CONFIG);
            $this->operadorService->update($operadorRow, self::ENTITY_DEFAULT_CONFIG);

            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
        }
    }

    public function salvarDadosAdicionais(
        array $row
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();
        $pessoaArray = $this->pessoaHService->getPessoaByNrParcNegocio($nrParcNegocio);
        $nrPessoaH = (int) $pessoaArray['NRPESSOAH'];

        $row['NRORG'] = $nrOrg;
        $row['CDOPERULTATU'] = $cdOperador;
        $row['NRPARCNEGOCIO'] = $nrParcNegocio;
        $row['DTULTATU'] = new \DateTime();
        $row['NRPESSOAH'] = $nrPessoaH;

        if (isset($row['DTVALHABCARTPES'])) {
            $row['DTVALHABCARTPES'] = DateUtil::getDataDeString($row['DTVALHABCARTPES']);
        }

        $this->entityManager->beginTransaction();

        try {
            $this->apresentacaoCandService->save($row);
            $this->pessoaHService->update($row);

            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function salvarEndereco(
        array $row
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $row['NRORG'] = $nrOrg;
        $row['NRPARCNEGOCIO'] = $nrParcNegocio;

        $findKeys = ['NRORG', 'NRPARCNEGOCIO'];

        $enderecoParc = $this->enderecoParcService->find($row, $findKeys);

        if ($enderecoParc) {
            $row['NRENDERECOPARC'] = $enderecoParc->getNrenderecoparc();
            $row['CDOPERULTATU'] = $cdOperador;
            $row['NRORGULTATU'] = $nrOrg;
            $row['DTULTATU'] = new \DateTime();
            $this->enderecoParcService->update($row);
        } else {
            $row['NRENDERECOPARC'] = NovoCodigo::geraCodigo($nrOrg, 'ENDERECOPARC');
            $row['CDOPERINCLUSAO'] = $cdOperador;
            $row['NRORGINCLUSAO'] = $nrOrg;
            $row['DTINCLUSAO'] = new \DateTime();
            $row['IDATIVO'] = 'S';
            $row['CDTIPOENDERECO'] = 'PRINCIPAL';
            $this->enderecoParcService->set($row);
        }
    }

    public function salvarContato(
        array $row
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $propCdFormaComu = [
            'REDESOCIAL' => '08',
            'HOMEPAGE' => '07',
            'TELPRINCIPAL' => [
                '01',
                function ($cdComunica) {
                    if (!$cdComunica) {
                        return null;
                    }

                    [$ddi, $ddd, $numero] = Util::getPhoneInfo($cdComunica);
                    return [$ddd, $numero];
                },
            ],
            'CELPARTIC' => [
                '02',
                function ($cdComunica) {
                    if (!$cdComunica) {
                        return null;
                    }

                    [$ddi, $ddd, $numero] = Util::getPhoneInfo($cdComunica);
                    return [$ddd, $numero];
                },
            ],
        ];

        $this->entityManager->beginTransaction();

        try {
            foreach ($propCdFormaComu as $prop => $cdFormaComu) {
                $cdPrefixo = null;
                $cdComunica = $row[$prop] ?? null;

                if ($cdComunica === '') {
                    $cdComunica = null;
                }

                if (is_array($cdFormaComu)) {
                    [$cdFormaComu, $fetcher] = $cdFormaComu;
                    [$cdPrefixo, $cdComunica] = $fetcher($cdComunica);
                }

                $comunicaRow = [
                    'NRORG' => $nrOrg,
                    'NRPARCNEGOCIO' => $nrParcNegocio,
                    'CDFORMACOMU' => $cdFormaComu,
                    'CDPREFIXCOMUPARC' => $cdPrefixo,
                    'CDCOMUNICAPARC' => $cdComunica,
                ];

                $findKeys = [
                    'NRORG', 'NRPARCNEGOCIO', 'CDFORMACOMU'
                ];

                /** @var Comunicaparc */
                $comunicaParc = $this->comunicaParcService->find($comunicaRow, $findKeys);

                if ($comunicaParc) {
                    if ($cdComunica) {
                        $comunicaRow['NRCOMUNICAPARC'] = $comunicaParc->getNrcomunicaparc();
                        $comunicaRow['CDOPERULTATU'] = $cdOperador;
                        $comunicaRow['NRORGULTATU'] = $cdOperador;
                        $comunicaRow['DTULTATU'] = new \DateTime();
                        $this->comunicaParcService->update($comunicaRow);
                    } else {
                        $rowRemove = [
                            'NRORG' => $nrOrg,
                            'NRCOMUNICAPARC' => $comunicaParc->getNrcomunicaparc(),
                        ];

                        $this->comunicaParcService->remove($rowRemove);
                    }
                } else {
                    if ($cdComunica) {
                        $comunicaRow['NRCOMUNICAPARC'] = NovoCodigo::geraCodigo($nrOrg, 'COMUNICAPARC', 1, 10, true, false);
                        $comunicaRow['CDOPERINCLUSAO'] = $cdOperador;
                        $comunicaRow['NRORGINCLUSAO'] = $cdOperador;
                        $comunicaRow['DTINCLUSAO'] = new \DateTime();
                        $this->comunicaParcService->set($comunicaRow);
                    }
                }
            }

            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

    public function salvarFormacao(
        array $row
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $row['NRORG'] = $nrOrg;
        $row['NRPARCNEGOCIO'] = $nrParcNegocio;

        if (isset($row['DTINICIO'])) {
            $row['DTINICIO'] = DateUtil::getDataDeString($row['DTINICIO']);
        }

        if (isset($row['DTFIM'])) {
            $row['DTFIM'] = DateUtil::getDataDeString($row['DTFIM']);
        }

        $formacao = null;

        if (isset($row['NRFORMACAO'])) {
            $findKeys = ['NRORG', 'NRPARCNEGOCIO', 'NRFORMACAO'];
            $formacao = $this->formacaoService->find($row, $findKeys);
        }

        if ($formacao) {
            $row['NRORGULTATU'] = $nrOrg;
            $row['CDOPERULTATU'] = $cdOperador;
            $row['DTULTATU'] = new \DateTime();
            unset($row['DTINCLUSAO']);
            unset($row['CDOPERINCLUSAO']);
            unset($row['NRORGINCLUSAO']);
            $this->formacaoService->update($row);
        } else {
            $row['NRORGINCLUSAO'] = $nrOrg;
            $row['CDOPERINCLUSAO'] = $cdOperador;
            $row['DTINCLUSAO'] = new \DateTime();
            $row['NRFORMACAO'] = NovoCodigo::geraCodigo($nrOrg, 'DES_FORMACAO');
            $this->formacaoService->set($row);
        }
    }

    public function excluirFormacao(
        int $nrFormacao
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $row = [
            'NRORG' => $nrOrg,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRFORMACAO' => $nrFormacao,
        ];

        $this->formacaoService->remove($row);
    }

    public function salvarExperiencia(
        array $row
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $row['NRORG'] = $nrOrg;
        $row['NRPARCNEGOCIO'] = $nrParcNegocio;

        if (isset($row['DTINICIO'])) {
            $row['DTINICIO'] = DateUtil::getDataDeString($row['DTINICIO']);
        }

        if (isset($row['DTFIM'])) {
            $row['DTFIM'] = DateUtil::getDataDeString($row['DTFIM']);
        }

        $experiencia = null;

        if (isset($row['NREMPREGOANTERIOR'])) {
            $findKeys = ['NRORG', 'NRPARCNEGOCIO', 'NREMPREGOANTERIOR'];
            $experiencia = $this->experienciaService->find($row, $findKeys);
        }

        if ($experiencia) {
            $row['NRORGULTATU'] = $nrOrg;
            $row['CDOPERULTATU'] = $cdOperador;
            $row['DTULTATU'] = new \DateTime();
            unset($row['DTINCLUSAO']);
            unset($row['CDOPERINCLUSAO']);
            unset($row['NRORGINCLUSAO']);
            $this->experienciaService->update($row);
        } else {
            $row['NRORGINCLUSAO'] = $nrOrg;
            $row['CDOPERINCLUSAO'] = $cdOperador;
            $row['DTINCLUSAO'] = new \DateTime();
            $row['NREMPREGOANTERIOR'] = NovoCodigo::geraCodigo($nrOrg, 'GPE_EMPREGANTERIOR');
            $this->experienciaService->set($row);
        }
    }

    public function excluirExperiencia(
        int $nrExperiencia
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $row = [
            'NRORG' => $nrOrg,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NREMPREGOANTERIOR' => $nrExperiencia,
        ];

        $this->experienciaService->remove($row);
    }

    public function salvarDocumento(
        array $row
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();
        $cdOperador = (string) $this->btParameters->getCdoperador();

        $path = $this->saveFileOnServer($row);
        $base64 = (string) $row['FILE'];

        $type = $this->utilities->getFileMIMEType($base64);
        $nrAnexo = NovoCodigo::geraCodigo($nrOrg, 'GPE_ANEXOS');

        $rowSet = [
            'CDOPERINCLUSAO' => $cdOperador,
            'NRORGINCLUSAO' => $nrOrg,
            'DTINCLUSAO' => new \DateTime(),
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'IDTYPE' => $type,
            'IDFOTO' => 'N',
            'NRANEXO' => $nrAnexo,
            'DSPATH' => $path,
            'DSREFERENCIA' => $row['DSREFERENCIA'],
            'NMANEXO' => $row['NMANEXO'],
            'IDDOCUMENTOMODELO' => 'N',
            'NRCATEGDOCUMENTO' => $row['NRCATEGDOCUMENTO'] ?? null,
            'NRTIPODOCUMENTO' => $row['NRTIPODOCUMENTO'] ?? null,
            'IDDOCAPROVADO' => 'S',
        ];

        $this->anexosService->set($rowSet);
    }

    private function saveFileOnServer(
        array $row
    ): string {
        $nrOrg = (int) $this->btParameters->getNrOrg();

        $base64 = (string) $row['FILE'];

        $directory = "BTL/$nrOrg/Documentos/";
        $name = (string) $row['NMANEXO'];

        $filePath = $this->utilities->saveFileOnFileServer(
            $base64, null, $nrOrg, $directory,
            $name, null, false
        );

        return $filePath;
    }

    public function excluirDocumento(
        int $nrAnexo
    ): void {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $row = [
            'NRORG' => $nrOrg,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRANEXO' => $nrAnexo,
        ];

        $anexo = $this->anexosService->find($row);
        $dsPath = $anexo->getDspath();

        $this->anexosService->remove($row);
        $this->utilities->deleteFile($dsPath);
    }

    public function downloadAnexo(
        int $nrAnexo
    ): array {
        $nrOrg = (int) $this->btParameters->getNrOrg();
        $nrParcNegocio = (int) $this->btParameters->getNrParcNegocio();

        $row = [
            'NRORG' => $nrOrg,
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRANEXO' => $nrAnexo,
        ];

        $anexo = $this->anexosService->find($row);
        $dsPath = $anexo->getDspath();

        $file = $this->utilities->downloadFile($dsPath);

        return $file;
    }
}