<?php

namespace BancoTalentos\Util;

use Zeedhi\Framework\Events\PreDispatch\Listener;
use Zeedhi\Framework\DTO\Request;
use BancoTalentos\Util\{ RequestUtils, Util };

class RouteValidations extends Listener {

    const INVALID_ACCESS_CODE = 10611;

    const PROJECT_PUBLIC_ROUTES = '/../../config/publicRoutes.json';
    const LIB_PUBLIC_ROUTES = '/../../vendor/teknisa/libraries/config/publicRoutes.json';

    // All JSON public routes files relative paths
    const PUBLIC_ROUTES_PATHS = [
        self::PROJECT_PUBLIC_ROUTES,
        self::LIB_PUBLIC_ROUTES,
    ];

    public function preDispatch(Request $request) {
        if ($this->validate($request)) {
            return;
        }

        throw new \Exception(Messages::OPER_ACCESS_INVALID, self::INVALID_ACCESS_CODE);
    }

    public function validate(Request $request): bool {
        $isIgnoredRoute = in_array($request->getRoutePath(), $this->getAllPublicRoutes());
        if ($isIgnoredRoute) {
            return true;
        }

        return Util::getParamters()->getNrOrg() == Util::DEFAULT_ORG;
    }

    public function getAllPublicRoutes(): Array {
        $publicRoutes = [];
        foreach (self::PUBLIC_ROUTES_PATHS as $publicRoutesPath) {
            $publicRoutesFile = @file_get_contents(__DIR__ . $publicRoutesPath);
            $publicRoutes = array_merge(json_decode($publicRoutesFile, true), $publicRoutes);
        }

        return $publicRoutes;
    }

}